rm(list=ls())
# Load required libraries

library(car)
library(ecodist)
library(vegan)
#library(VennDiagram)
library(Hmisc)

# Read in the shared file from mothur, the two habitats must be separated from one another i.e., all the samples belonging to habitat 1 must be sequentially arranged one after the other and same for habitat 2
# Also replace "Otu0001" as 1, "Otu0001", as 2, and so on using find and replace function in EXCEL
rS<-read.csv("H:/PhD/Results/Sampling/Survey-NCM/Survey_Illumina/NCM_PILOT3/NCM-PILOT3.csv",check.names=FALSE)
dim(rS)
# Choose relevant columns from the shared file
dS=rS[,2:ncol(rS)]
write.table(dS,file="H:/PhD/Results/Sampling/Survey-NCM/Survey_Illumina/NCM_PILOT3/JUST_NCM_FTR.csv",sep="\t",row.names=FALSE,col.names=TRUE)
vG=read.delim("H:/PhD/Results/Sampling/Survey-NCM/Survey_Illumina/NCM_PILOT3/JUST_NCM_FTR.csv",check.names=FALSE)
allOTUs<-as.numeric(colnames(vG))
# Indicate number of rows for lung OR Target community and create a new matrix with the target community
nBact=8

Bact=dS[1:nBact,]
# Create a matrix with the source community
Bacs=dS[9:nrow(rS),]

# Calculate frequency and relative abundance of each OTU in the target community (in this case it is the lung)

Bactfreq=c()
for (i in 1:ncol(Bact)){
	Bactfreq[i]=length(which(Bact[,i]>0))/nrow(Bact)
	}


	
Bactpi=colMeans(Bact)

# Calculate frequency and relative abundance of each OTU in the source community (in this case it is the mouth)
Bacsfreq=c()
for (i in 1:ncol(Bacs)){
	Bacsfreq[i]=length(which(Bacs[,i]>0))/nrow(Bacs)
	}
	
Bacspi=colMeans(Bacs)

colind=c(1:ncol(Bact))

Bac_neutral_data=matrix(nrow=length(Bactfreq),ncol=6)


for (i in 1:nrow(Bac_neutral_data)){
	
	Bac_neutral_data[i,1]=Bactfreq[i]
	Bac_neutral_data[i,2]=Bactpi[i]
	Bac_neutral_data[i,3]=Bacsfreq[i]
	Bac_neutral_data[i,4]=Bacspi[i]
	Bac_neutral_data[i,5]=colind[i]
	Bac_neutral_data[i,6]=allOTUs[i]
}

# Sort the OTUs by their abundance in the source community just like the neutral model in the excel spreadsheet for the neutral model 
Bac_neutral_data_sorted=Bac_neutral_data[order(Bac_neutral_data[,4],decreasing=TRUE),]
write.table(Bac_neutral_data_sorted,file="H:/PhD/Results/Sampling/Survey-NCM/Survey_Illumina/NCM_PILOT3/BAC.TOT_FTR.txt",sep="\t",row.names=FALSE,col.names=c("Reactor_freq","Reactor_abund","Source_freq","Source_abund","Col_ind","OTU#"))
reactor=length(which(Bac_neutral_data_sorted[,1]>0))
source=length(which(Bac_neutral_data_sorted[,3]>0))

shared=length(which(Bac_neutral_data_sorted[,1]>0 & Bac_neutral_data_sorted[,3]>0))
#quartz()
#draw.pairwise.venn(source,reactor,shared,col=c("red","black"),fill=c("indianred","black"),label.col=c("white"))
# consider only shared OTUs b/w the target and source
onlyshared=which(Bac_neutral_data_sorted[,1]>0)
passthrough=which(Bac_neutral_data_sorted[,2]==0&Bac_neutral_data_sorted[,4]>0)
reaconly=which(Bac_neutral_data_sorted[,2]>0&Bac_neutral_data_sorted[,4]==0)

passthrough1=subset(Bac_neutral_data_sorted[passthrough,])
reaconly1=subset(Bac_neutral_data_sorted[reaconly,])
write.table(passthrough1,file="H:/PhD/Results/Sampling/Survey-NCM/Survey_Illumina/NCM_PILOT3/passthrough_FTR.txt",sep="\t",row.names=FALSE,col.names=c("Reactor_freq","Reactor_abund","Source_freq","Source_abund","Col_ind","OTU#"))
write.table(reaconly1,file="H:/PhD/Results/Sampling/Survey-NCM/Survey_Illumina/NCM_PILOT3/reactonly_FTR.txt",sep="\t",row.names=FALSE,col.names=c("Reactor_freq","Reactor_abund","Source_freq","Source_abund","Col_ind","OTU#"))


Bac_neutral_data_final=subset(Bac_neutral_data_sorted[onlyshared,])

# 2.05e-5 is the minimum abundance detected
col=which(Bac_neutral_data_final[,4]>=1.68e-7)
Bac_neutral_data_final_1=matrix(nrow=length(col),ncol=6)
for (i in 1:length(col)){
	
	Bac_neutral_data_final_1[i,1]= Bac_neutral_data_final[i,1]
	Bac_neutral_data_final_1[i,2]= Bac_neutral_data_final[i,2]
	Bac_neutral_data_final_1[i,3]= Bac_neutral_data_final[i,3]
	Bac_neutral_data_final_1[i,4]= Bac_neutral_data_final[i,4]
	Bac_neutral_data_final_1[i,5]= Bac_neutral_data_final[i,5]
	Bac_neutral_data_final_1[i,6]= Bac_neutral_data_final[i,6]
}

write.table(Bac_neutral_data_final_1,file="H:/PhD/Results/Sampling/Survey-NCM/Survey_Illumina/NCM_PILOT3/Bac_shared_FTR.txt",sep="\t",row.names=FALSE,col.names=c("Reactor_freq","Reactor_abund","Source_freq","Source_abund","Col_ind","OTU#"))

obs=read.delim("H:/PhD/Results/Sampling/Survey-NCM/Survey_Illumina/NCM_PILOT3/Bac_shared_FTR.txt")
print(dim(obs))
detlim=obs[nrow(obs),4]
# Vary Ntm from 1 to 100 in steps of 0.5
Ntm= seq(1,100000,500)

objfun= matrix(nrow=length(Ntm),ncol=2)


for (j in 1:length(Ntm)){
	
	Ntmloop=Ntm[j]
	
	neutralmatrix= matrix(nrow=nrow(obs),ncol=5)
	
	
		for (i in 1:nrow(obs)){
		neutralmatrix[i,1]=  Ntmloop*obs[i,4]
	}
		for (i in 1:nrow(obs)){
		neutralmatrix[i,2]=  Ntmloop*(1-obs[i,4])
	}
		for (i in 1:nrow(obs)){
		neutralmatrix[i,3]= pbeta(detlim,neutralmatrix[i,1],neutralmatrix[i,2])
	}
	for (i in 1:nrow(obs)){
		neutralmatrix[i,4]= 1-neutralmatrix[i,3]
	}
	for (i in 1:nrow(obs)){
		neutralmatrix[i,5]= (obs[i,1]-neutralmatrix[i,4])^2
	}
	sumcolumns=colSums(neutralmatrix)
	
	
	objfun[j,1]=sumcolumns[5]
	objfun[j,2]=Ntmloop
}


#determine the best minimum objective function
minobj=which.min(objfun[,1])
minobjfun=objfun[minobj[1],1]

#determine the best Ntm value
bestNtm=objfun[minobj[1],2]

#calculate all the parameters for the best neutral model
bestneutralmatrix= matrix(nrow=nrow(obs),ncol=9)

		for (i in 1:nrow(obs)){
		bestneutralmatrix[i,1]=  bestNtm*obs[i,4]
	}
		for (i in 1:nrow(obs)){
		bestneutralmatrix[i,2]=  bestNtm*(1-obs[i,4])
	}
		for (i in 1:nrow(obs)){
		bestneutralmatrix[i,3]= pbeta(detlim,bestneutralmatrix[i,1],bestneutralmatrix[i,2])
	}
	for (i in 1:nrow(obs)){
		bestneutralmatrix[i,4]= 1-bestneutralmatrix[i,3]
	}
	for (i in 1:nrow(obs)){
		bestneutralmatrix[i,5]= (obs[i,1]-bestneutralmatrix[i,4])^2
	}
		for (i in 1:nrow(obs)){
		bestneutralmatrix[i,6]= (obs[i,5])
		}
		for (i in 1:nrow(obs)){
		bestneutralmatrix[i,7]= (obs[i,6])
		}
		for (i in 1:nrow(obs)){
		bestneutralmatrix[i,8]= binconf(x=nrow(Bact)*bestneutralmatrix[i,4],n=nrow(Bact),alpha=0.05,method="wilson")[2]
		}
			for (i in 1:nrow(obs)){
		bestneutralmatrix[i,9]= binconf(x=nrow(Bact)*bestneutralmatrix[i,4],n=nrow(Bact),alpha=0.05,method="wilson")[3]
		}


		
OTUlist_environmental=c()
	j=1;
	
	for (i in 1:nrow(bestneutralmatrix)){
		j=j
		
		#diff= abs(bestneutralmatrix[i,4]-obs[i,2])
    # Choose the outliers based upon the confidence limits and the ratio of the observed frequency and the value predicted by the neutral model
		diff=(obs[i,1]/bestneutralmatrix[i,4])
		if (diff >=1.5 & obs[i,1]>= bestneutralmatrix[i,9]){
			OTUlist_environmental[j]=bestneutralmatrix[i,6]
			j=j+1
			
		}
		
	}

OTUlist_environmental_against=c()
	j=1;
		for (i in 1:nrow(bestneutralmatrix)){
		j=j
		
		#diff= abs(bestneutralmatrix[i,4]-obs[i,2])
		diff=(obs[i,1]/bestneutralmatrix[i,4])
		if (diff <=0.75 & obs[i,1]<=bestneutralmatrix[i,8]){
			OTUlist_environmental_against[j]=bestneutralmatrix[i,6]
			j=j+1
			
		}
		
	}

    "%w/o%" <- function(x, y) x[!x %in% y] #--  x without y
	vf=c(OTUlist_environmental,OTUlist_environmental_against)
	OTUlist_neutral= obs[,5] %w/o% vf
	
	dd_env=which(obs[,5] %in% OTUlist_environmental)
environmental_matrix=matrix(nrow=length(dd_env),ncol=6)
for (i in 1:length(dd_env)){
	environmental_matrix[i,1]=obs[dd_env[i],1]
	environmental_matrix[i,2]=obs[dd_env[i],2]
	environmental_matrix[i,3]=obs[dd_env[i],3]
	environmental_matrix[i,4]=obs[dd_env[i],4]
	environmental_matrix[i,5]=obs[dd_env[i],5]
	environmental_matrix[i,6]=obs[dd_env[i],6]
	
}
write.table(environmental_matrix,file="H:/PhD/Results/Sampling/Survey-NCM/Survey_Illumina/NCM_PILOT3/Bac.env.sel.FOR_Survey_FTR.txt",sep="\t",row.names=FALSE,col.names=c("Reactor_freq","Reactor_abund","Source_freq","Source_abund","Col_ind","OTU#"))
	dd_against=which(obs[,5] %in% OTUlist_environmental_against)		
environmental_against_matrix=matrix(nrow=length(dd_against),ncol=6)
for (i in 1:length(dd_against)){
	environmental_against_matrix[i,1]=obs[dd_against[i],1]
	environmental_against_matrix[i,2]=obs[dd_against[i],2]
	environmental_against_matrix[i,3]=obs[dd_against[i],3]
	environmental_against_matrix[i,4]=obs[dd_against[i],4]
	environmental_against_matrix[i,5]=obs[dd_against[i],5]
	environmental_against_matrix[i,6]=obs[dd_against[i],6]
}

write.table(environmental_against_matrix,file="H:/PhD/Results/Sampling/Survey-NCM/Survey_Illumina/NCM_PILOT3/Bac.env.sel.AGAINST_Survey_FTR.txt",sep="\t",row.names=FALSE,col.names=c("Reactor_freq","Reactor_abund","Source_freq","Source_abund","Col_ind","OTU#"))
dd_neut=which(obs[,5] %in% OTUlist_neutral)
neutral_matrix=matrix(nrow=length(dd_neut),ncol=6)
for (i in 1:length(dd_neut)){
	neutral_matrix[i,1]=obs[dd_neut[i],1]
	neutral_matrix[i,2]=obs[dd_neut[i],2]
	neutral_matrix[i,3]=obs[dd_neut[i],3]
	neutral_matrix[i,4]=obs[dd_neut[i],4]
	neutral_matrix[i,5]=obs[dd_neut[i],5]
	neutral_matrix[i,6]=obs[dd_neut[i],6]
}
write.table(neutral_matrix,file="H:/PhD/Results/Sampling/Survey-NCM/Survey_Illumina/NCM_PILOT3/Bac.NEUTRAL_FTR.txt",sep="\t",row.names=FALSE,col.names=c("Reactor_freq","Reactor_abund","Source_freq","Source_abund","Col_ind","OTU#"))	
	
#	quartz()
jpeg("H:/PhD/Results/Sampling/Survey-NCM/Survey_Illumina/NCM_PILOT3/FTR.jpeg", quality=100, width = 500, height = 500)

	plot(obs[,4]*100,bestneutralmatrix[,4]*100,type="l",col="black",lwd=2,xlab="Mean relative abundance in filter (%)",ylab="Detection frequency in effluents (%)",cex.lab=1.5,log="x",xlim=c(0.0008,10))
	lines(obs[,4]*100,bestneutralmatrix[,8]*100,type="l",col="black",lwd=2,lty=2)
	lines(obs[,4]*100,bestneutralmatrix[,9]*100,type="l",col="black",lwd=2,lty=2)
	points(jitter(neutral_matrix[,4]*100),neutral_matrix[,1]*100,col="darkgrey",pch=16,cex=1.1)
	points(jitter(environmental_against_matrix[,4]*100),environmental_against_matrix[,1]*100,col="indianred",pch=16,cex=1.1)	
	points(jitter(environmental_matrix[,4]*100),environmental_matrix[,1]*100,col="darkgreen",pch=16,cex=1.1)
	print(minobjfun)
	print(bestNtm)
	correlcoeff= cor.test(obs[,1],bestneutralmatrix[,4])
	print(correlcoeff)
	correlcoeff2= cor.test(obs[,1],bestneutralmatrix[,4],method="spearman")
	print(correlcoeff2)
	
	
